==> 0.0.2.tar.gz: android/src/main/kotlin/com/ahazou/watermark_shareable/utils/Constants.kt <==
package com.ahazou.watermark_shareable


import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Canvas
import android.graphics.Matrix
import android.graphics.drawable.BitmapDrawable
import android.graphics.drawable.Drawable

class Constants {
  companion object{
    fun decodeSampledBitmapFromResource(res: String?): Bitmap {
      val options = BitmapFactory.Options()
      options.inJustDecodeBounds = true
      BitmapFactory.decodeFile(res, options)
      options.inJustDecodeBounds = false
      return BitmapFactory.decodeFile(res, options)
    }


    @JvmStatic
    fun calculateInSampleSize(options: BitmapFactory.Options, reqWidth: Int, reqHeight: Int): Int {
      val height = options.outHeight
      val width = options.outWidth
      var inSampleSize = 1

      if (height > reqHeight || width > reqWidth) {

        val halfHeight = height / 2
        val halfWidth = width / 2
        while (halfHeight / inSampleSize >= reqHeight && halfWidth / inSampleSize >= reqWidth) {
          inSampleSize *= 2
        }
      }

      return inSampleSize
    }

    @JvmStatic
    fun overlay(bmp1: Bitmap?, bmp2: Bitmap?): Bitmap {
      val bmOverlay = Bitmap.createBitmap(bmp1!!.width, bmp1.height, bmp1.config)
      val canvas = Canvas(bmOverlay)
      canvas.drawBitmap(bmp1, Matrix(), null)
      canvas.drawBitmap(bmp2!!, (bmp1.width.toFloat() - 57f), ((bmp1.height - bmp2!!.height) / 2).toFloat(), null)
      return bmOverlay
    }

    @JvmStatic
    fun drawableToBitmap(drawable: Drawable?): Bitmap {
      if (drawable is BitmapDrawable) {
        return drawable.bitmap
      }

      val width = if (!drawable?.bounds!!.isEmpty)
        drawable.bounds.width()
      else
        drawable.intrinsicWidth

      val height = if (!drawable.bounds.isEmpty)
        drawable.bounds.height()
      else
        drawable.intrinsicHeight

      val bitmap = Bitmap.createBitmap(if (width <= 0) 1 else width, if (height <= 0) 1 else height, Bitmap.Config.RGB_565)
      val canvas = Canvas(bitmap)
      drawable.setBounds(0, 0, canvas.width, canvas.height)
      drawable.draw(canvas)

      return bitmap
    }

  }
}

==> 0.0.3.tar.gz: android/src/main/kotlin/com/ahazou/watermark_shareable/utils/Constants.kt <==
package com.ahazou.watermark_shareable


import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Canvas
import android.graphics.Matrix
import android.graphics.drawable.BitmapDrawable
import android.graphics.drawable.Drawable

class Constants {
  companion object{
    fun decodeSampledBitmapFromResource(res: String?): Bitmap {
      val options = BitmapFactory.Options()
      options.inJustDecodeBounds = true
      BitmapFactory.decodeFile(res, options)
      options.inJustDecodeBounds = false
      return BitmapFactory.decodeFile(res, options)
    }


    @JvmStatic
    fun calculateInSampleSize(options: BitmapFactory.Options, reqWidth: Int, reqHeight: Int): Int {
      val height = options.outHeight
      val width = options.outWidth
      var inSampleSize = 1

      if (height > reqHeight || width > reqWidth) {

        val halfHeight = height / 2
        val halfWidth = width / 2
        while (halfHeight / inSampleSize >= reqHeight && halfWidth / inSampleSize >= reqWidth) {
          inSampleSize *= 2
        }
      }

      return inSampleSize
    }

    @JvmStatic
    fun overlay(bmp1: Bitmap?, bmp2: Bitmap?): Bitmap {
      val bmOverlay = Bitmap.createBitmap(bmp1!!.width, bmp1.height, bmp1.config)
      val canvas = Canvas(bmOverlay)
      canvas.drawBitmap(bmp1, Matrix(), null)
      canvas.drawBitmap(bmp2!!, (bmp1.width.toFloat() - 55f), ((bmp1.height - bmp2.height) / 2).toFloat(), null)
      return bmOverlay
    }

    @JvmStatic
    fun drawableToBitmap(drawable: Drawable?): Bitmap {
      if (drawable is BitmapDrawable) {
        return drawable.bitmap
      }

      val width = if (!drawable?.bounds!!.isEmpty)
        drawable.bounds.width()
      else
        drawable.intrinsicWidth

      val height = if (!drawable.bounds.isEmpty)
        drawable.bounds.height()
      else
        drawable.intrinsicHeight

      val bitmap = Bitmap.createBitmap(if (width <= 0) 1 else width, if (height <= 0) 1 else height, Bitmap.Config.RGB_565)
      val canvas = Canvas(bitmap)
      drawable.setBounds(0, 0, canvas.width, canvas.height)
      drawable.draw(canvas)

      return bitmap
    }

  }
}
